@@ -17,6 +17,7 @@ handler500 = 'coop.views.SentryHandler500'
 
 urlpatterns += patterns('',
 
+
     #Testing webid urls
     url(r'^accounts/webidauth', 'coop.webid.views.test_login',
         name="webidauth-login"),
@@ -41,6 +42,10 @@ urlpatterns += patterns('',
     url(r'^reset/done/$', 'django.contrib.auth.views.password_reset_complete'),
     #url(r'^org/$', 'coop_local.views.org_list', name="org_list"),  # exemple de view django-coop surchargee
 
+    # sympa test
+    url(r'^sympa_remote_list/(?P<name>\w+)$', 'coop.mailing.views.list'),
+
+
 )
 
 # URLS for all Classification models
@@ -60,7 +65,7 @@ urlpatterns += patterns('',
 
 
 # for local testing
-if settings.DEBUG or ('test' in sys.argv):
+if settings.DEBUG or ('test' in sys.argv) or ('runserver' in sys.argv):
     urlpatterns += staticfiles_urlpatterns()
     urlpatterns += patterns('',
         (r'^media/(?P<path>.*)$', 'django.views.static.serve', {'document_root': settings.MEDIA_ROOT, 'show_indexes': True}),
@@ -89,5 +94,6 @@ urlpatterns += patterns('',
 
 if settings.DEBUG:
     urlpatterns += patterns('',
-        url(r'^', include('debug_toolbar_user_panel.urls')),
-    )
+    # url(r'^', include('debug_toolbar_htmltidy.urls'))
+    # url(r'^', include('debug_toolbar_user_panel.urls')),
+)
