@@ -35,7 +35,17 @@ INSTALLED_APPS = settings.INSTALLED_APPS + [
     'coop.exchange',
     #'coop.webid',
     'coop_local',
+     # coop optional modules
+    'coop_geo',  # est obligatoirement APRES coop_local
 
-    # coop optional modules
-    'coop_geo',  # est obligatoirement placé APRES coop_local
-]
\ No newline at end of file
+]
+
+# TODO: to be discuss this settings could be in default_project_setings.py
+# file. To be check I knew more on how to configure sympa
+SYMPA_SOAP = {
+    'WSDL': 'http://sympa.{{ domain }}/sympa/wsdl',
+    'APPNAME': 'djangoapp',
+    'PASSWORD': 'test',
+    'OWNER': 'USER_EMAIL=userProxy@my.server',
+    'PARAMETER_SEPARATOR': '__SEP__',      # used for template
+}
