@@ -26,9 +26,11 @@ if "coop_tag" in settings.INSTALLED_APPS:
             help_text="Une liste de tags avec des virgules")
     t.contribute_to_class(Organization, "tags")
     t.contribute_to_class(Person, "tags")
-    t.contribute_to_class(Article, "tags")
+    if "coop_cms" in settings.INSTALLED_APPS:
+        t.contribute_to_class(Article, "tags")
     if "coop.exchange" in settings.INSTALLED_APPS:
         t.contribute_to_class(Exchange, "tags")
-
+    if "coop.agenda" in settings.INSTALLED_APPS:
+        t.contribute_to_class(Event, "tags")
 
 
